==> mapserver-4.0b.tar.gz: mapserver-4.0b/mapparser.h <==
/* A Bison parser, made from mapparser.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_MAPPARSER_H
# define BISON_MAPPARSER_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NUMBER = 258,
     STRING = 259,
     REGEX = 260,
     OR = 261,
     AND = 262,
     NOT = 263,
     IN = 264,
     GE = 265,
     LE = 266,
     GT = 267,
     LT = 268,
     NE = 269,
     EQ = 270,
     RE = 271,
     LENGTH = 272,
     NEG = 273
   };
#endif
#define NUMBER 258
#define STRING 259
#define REGEX 260
#define OR 261
#define AND 262
#define NOT 263
#define IN 264
#define GE 265
#define LE 266
#define GT 267
#define LT 268
#define NE 269
#define EQ 270
#define RE 271
#define LENGTH 272
#define NEG 273




#ifndef YYSTYPE
#line 24 "mapparser.y"
typedef union {
  double dblval;
  int intval;  
  char *strval;
} yystype;
/* Line 1281 of /usr/local/share/bison/yacc.c.  */
#line 82 "mapparser.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE msyylval;


#endif /* not BISON_MAPPARSER_H */

==> mapserver-4.4.0.tar.gz: mapserver-4.4.0/mapparser.h <==
/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NUMBER = 258,
     STRING = 259,
     TIME = 260,
     REGEX = 261,
     OR = 262,
     AND = 263,
     NOT = 264,
     IN = 265,
     GE = 266,
     LE = 267,
     GT = 268,
     LT = 269,
     NE = 270,
     EQ = 271,
     RE = 272,
     LENGTH = 273,
     NEG = 274
   };
#endif
#define NUMBER 258
#define STRING 259
#define TIME 260
#define REGEX 261
#define OR 262
#define AND 263
#define NOT 264
#define IN 265
#define GE 266
#define LE 267
#define GT 268
#define LT 269
#define NE 270
#define EQ 271
#define RE 272
#define LENGTH 273
#define NEG 274




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 24 "mapparser.y"
typedef union YYSTYPE {
  double dblval;
  int intval;  
  char *strval;  
  struct tm tmval;
} YYSTYPE;
/* Line 1248 of yacc.c.  */
#line 81 "mapparser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE msyylval;
